==> guikachu-0.3.tar.gz: guikachu-0.3/src/treeitem.cc <==
//$Id: treeitem.cc,v 1.4 2001/03/06 18:25:15 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "treeitem.h"

#include "config.h"
#include <libgnome/libgnome.h>

#include <gnome--/app-helper.h>
#include <libgnomeui/gnome-stock.h>
#include <list>

using namespace Guikachu;
using namespace Gnome;

GUI::TreeItem::TreeItem (Resources::Resource *res_):
    Gtk::TreeItem (res_->get_id ()),
    res (res_)
{
    button_press_event.connect (slot (this, &GUI::TreeItem::button_press_cb));
    key_press_event.connect (slot (this, &GUI::TreeItem::key_press_cb));
    
    res->changed.connect (slot (this, &GUI::TreeItem::resource_changed_cb));
    
    list <UI::Info> popup_menu_list;
    popup_menu_list.push_back (
	UI::Item (UI::Icon (GNOME_STOCK_PIXMAP_TRASH),
		  _("Remove"),
		  SigC::slot (this, &GUI::TreeItem::remove_cb)));
    UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
}

int GUI::TreeItem::key_press_cb (GdkEventKey *e)
{
    switch (e->keyval)
    {
    case GDK_Return:
    case GDK_KP_Enter:
	res->show_ui ();
	break;
	
    case GDK_Delete:
    case GDK_KP_Delete:	
	remove_cb ();
	break;

    default:
	break;
    }

    return true;
}

int GUI::TreeItem::button_press_cb (GdkEventButton *e)
{
    if (e->type == GDK_2BUTTON_PRESS && e->button == 1)
	res->show_ui ();

    if (e->button == 3)
	popup_menu.popup (e->button, e->time);
    
    return false;
    
}

void GUI::TreeItem::resource_changed_cb ()
{
    remove ();
    add_label (res->get_id ());
}

void GUI::TreeItem::remove_cb ()
{
    ResourceManager::remove_resource (res);
}

==> guikachu-0.98.0.tar.gz: guikachu-0.98.0/src/treeitem.cc <==
//$Id: treeitem.cc,v 1.5 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "treeitem.h"

#include "config.h"
#include <libgnome/libgnome.h>

#include <gnome--/app-helper.h>
#include <libgnomeui/gnome-stock.h>
#include <list>

using namespace Guikachu;
using namespace Gnome;

GUI::TreeItem::TreeItem (Resources::Resource *res_):
    Gtk::TreeItem (res_->id),
    res (res_)
{
    button_press_event.connect (slot (this, &GUI::TreeItem::button_press_cb));
    key_press_event.connect (slot (this, &GUI::TreeItem::key_press_cb));
    
    res->changed.connect (slot (this, &GUI::TreeItem::resource_changed_cb));
    
    list <UI::Info> popup_menu_list;
    popup_menu_list.push_back (
	UI::Item (UI::Icon (GNOME_STOCK_PIXMAP_TRASH),
		  _("Remove"),
		  SigC::slot (this, &GUI::TreeItem::remove_cb)));
    UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
}

int GUI::TreeItem::key_press_cb (GdkEventKey *e)
{
    switch (e->keyval)
    {
    case GDK_Return:
    case GDK_KP_Enter:
	res->show_ui ();
	break;
	
    case GDK_Delete:
    case GDK_KP_Delete:	
	remove_cb ();
	break;

    default:
	break;
    }

    return true;
}

int GUI::TreeItem::button_press_cb (GdkEventButton *e)
{
    if (e->type == GDK_2BUTTON_PRESS && e->button == 1)
	res->show_ui ();

    if (e->button == 3)
	popup_menu.popup (e->button, e->time);
    
    return false;
    
}

void GUI::TreeItem::resource_changed_cb ()
{
    remove ();
    add_label (res->id);
}

void GUI::TreeItem::remove_cb ()
{
    ResourceManager::remove_resource (res);
}
